@@ -35,15 +35,7 @@
 	?>
 	<div class="box">
 		<div class="box_top">
-			<?php 
-				if (isset($schedule['schedule_type_id']) && $schedule['schedule_type_id'] == 2) { //task
-					echo $lang['hdr_schedule_task'];
-				}
-				elseif (isset($schedule['schedule_type_id'])) { //event
-					echo $lang['hdr_schedule_event'];
-				}
-			?>
-			<br />
+			<?php echo $lang['hdr_schedule_item'];?><br />
 		</div>
 		
 		<div class="box_mid">
@@ -55,40 +47,40 @@
 					?>
 					
 					<?php
-					if ($me['user_id'] == $schedule_item['user_id']) {
+					if ($me['user_id'] == $schedule['user_id']) {
 					?>
-					<a href="sch_edit.php?schedule_item_id=<?php echo $schedule_item['schedule_item_id'];?>"><?php echo $lang['href_edit'];?></a>
+					<a href="sch_edit.php?schedule_id=<?php echo $schedule['schedule_id'];?>"><?php echo $lang['href_edit'];?></a>
 					,&nbsp;
 					<?php }?>
 					
 					<?php
-					if (isset($schedule_item['bookmark']['watch'])) {
+					if (isset($schedule['bookmark']['watch'])) {
 					?>
-					<a href="sch_view.php?schedule_item_id=<?php echo $schedule_item['schedule_item_id'];?>&amp;bookmark=del_mark"><?php echo $lang['href_unwatch_this'];?></a>
+					<a href="sch_view.php?schedule_id=<?php echo $schedule['schedule_id'];?>&amp;bookmark=del_mark"><?php echo $lang['href_unwatch_this'];?></a>
 					<?php
 					}
 					else {
 					?>
-					<a href="sch_view.php?schedule_item_id=<?php echo $schedule_item['schedule_item_id'];?>&amp;bookmark=ins_mark"><?php echo $lang['href_watch_this'];?></a>
+					<a href="sch_view.php?schedule_id=<?php echo $schedule['schedule_id'];?>&amp;bookmark=ins_mark"><?php echo $lang['href_watch_this'];?></a>
 					<?php }?>
 					,&nbsp;
 					
 					<?php
-					if (isset($schedule_item['bookmark']['recommend'])) {
+					if (isset($schedule['bookmark']['recommend'])) {
 					?>
-					<a href="sch_view.php?schedule_item_id=<?php echo $schedule_item['schedule_item_id'];?>&amp;bookmark=del_tip"><?php echo $lang['href_unrecommend_this'];?></a>
+					<a href="sch_view.php?schedule_id=<?php echo $schedule['schedule_id'];?>&amp;bookmark=del_tip"><?php echo $lang['href_unrecommend_this'];?></a>
 					<?php
 					}
 					else {
 					?>
-					<a href="sch_view.php?schedule_item_id=<?php echo $schedule_item['schedule_item_id'];?>&amp;bookmark=ins_tip"><?php echo $lang['href_recommend_this'];?></a>
+					<a href="sch_view.php?schedule_id=<?php echo $schedule['schedule_id'];?>&amp;bookmark=ins_tip"><?php echo $lang['href_recommend_this'];?></a>
 					<?php }?>
 					
 					<?php
-					if (!isset($schedule_item['bookmark']['watch']) && $batch_enabled == true) {
+					if (!isset($schedule['bookmark']['watch']) && isset($batch_enabled) && $batch_enabled == true) {
 					?>
 					,&nbsp;
-					<a href="sch_view.php?schedule_item_id=<?php echo $schedule_item['schedule_item_id'];?>&amp;bookmark=ins_mark&amp;notify=1"><?php echo $lang['href_watch_this_notify'];?></a>
+					<a href="sch_view.php?schedule_id=<?php echo $schedule['schedule_id'];?>&amp;bookmark=ins_mark&amp;notify=1"><?php echo $lang['href_watch_this_notify'];?></a>
 					<?php }?>
 					<?php }?>
 					<br />
@@ -222,13 +214,22 @@
 						<?php
 						if (isset($schedule['rsp'])) {
 							foreach($schedule['rsp'] as $key => $i):
+								if (!empty($i['degree_id']) && $i['level_id'] == $rspconfig['rsp_level']['node']) {
+									echo $lang['rsp']['rsp_level_degree'][$i['degree_id']];
+								}
+								else {
+									echo trim($lang['rsp']['rsp_level'][$i['level_id']]);
+								}
+								echo " (" .$lang['rsp']['status'][$i['status_id']];
 								
-								echo trim($lang['rsp']['rsp_level'][$i['level_id']] . " " . $i['degree_id']);
-								echo " (" .$lang['rsp']['status'][$i['status_id']] . ")";
+								if (!empty($i['rsp_featured'])) {
+									echo " &amp; " .  $lang['txt_featured'];
+								}
+								
+								echo ")";
 								if ($key+1 < count($schedule['rsp'])) {
 									echo ", ";
 								}
-								
 							endforeach;
 						}
 						?>
@@ -270,8 +271,8 @@
 						$hidden_form['group_id'] = $group['group_id'];
 					}
 				
-				if (isset($schedule_item['user_id'])) {
-					$hidden_form['item_user_id'] = $schedule_item['user_id'];
+				if (isset($schedule['user_id'])) {
+					$hidden_form['item_user_id'] = $schedule['user_id'];
 				}
 					
 					include $templatePath . "comment.inc.tpl.php";
@@ -455,11 +456,11 @@
 					?>
 					<tr>
 						<td width="1" rowspan="2">
-							<a href="sch_view.php?schedule_item_id=<?php echo $i['schedule_item_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
+							<a href="sch_view.php?schedule_id=<?php echo $i['schedule_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
 						</td>
 						<td valign="top">
-							<a href="sch_view.php?schedule_item_id=<?php echo $i['schedule_item_id'];?>"><?php echo $this->date->formatDate($i['schedule_item_create_datetime'], 1);?></a><br />
-							<?php echo $i['schedule_item_title'];?><br />
+							<a href="sch_view.php?schedule_id=<?php echo $i['schedule_id'];?>"><?php echo $this->date->formatDate($i['schedule_create_datetime'], 1);?></a><br />
+							<?php echo $i['schedule_title'];?><br />
 						</td>
 						<td valign="top" align="right">
 							<?php echo $lang['href_comments'];?>&nbsp;(<?php if (!empty($i['comment_total'])) { echo $i['comment_total'];} else { echo "0";}?>)
@@ -610,11 +611,11 @@
 					?>
 					<tr>
 						<td width="32" rowspan="2">
-							<a href="sch_view.php?schedule_item_id=<?php echo $i['schedule_item_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
+							<a href="sch_view.php?schedule_id=<?php echo $i['schedule_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
 						</td>
 						<td valign="top" nowrap="nowrap">
-							<a href="sch_view.php?schedule_item_id=<?php echo $i['schedule_item_id'];?>"><?php echo $this->date->formatDate($i['schedule_item_create_datetime'], 1);?></a><br />
-							<?php echo $i['schedule_item_title'];?><br />
+							<a href="sch_view.php?schedule_id=<?php echo $i['schedule_id'];?>"><?php echo $this->date->formatDate($i['schedule_create_datetime'], 1);?></a><br />
+							<?php echo $i['schedule_title'];?><br />
 						</td>
 						<td valign="top">
 							<?php echo $lang['href_comments'];?>&nbsp;(<?php if (!empty($i['comment_total'])) { echo $i['comment_total'];} else { echo "0";}?>)
@@ -1139,15 +1140,15 @@
 				
 				<?php }?>
 				<?php
-				if (isset($schedule_item)) {
+				if (isset($schedule)) {
 				if (isset($group)) {
 				?>
-				<a href="sch_view.php?group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_list_schedule_item'];?></a><br />
+				<a href="sch_view.php?group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_group_schedule'];?></a><br />
 				<?php
 				}
 				else {
 				?>
-				<a href="sch_view.php?user_id=<?php echo $schedule_item['user_id'];?>"><?php echo $lang['href_list_schedule_item'];?></a><br />
+				<a href="sch_view.php?user_id=<?php echo $schedule['user_id'];?>"><?php echo $lang['href_network_schedule'];?></a><br />
 				<?php }}?>
 				
 				<?php
@@ -1187,14 +1188,8 @@
 						foreach ($item_tags as $key => $i):
 							$tags .= "<a href='search.php?tag=" . $i['tag_body']. "'>" . $i['tag_body'] . "</a>";
 							
-							//mark my tags
-							if (isset($my_tags)) {
-								foreach ($my_tags as $key => $mt):
-									if ($i['tag_body'] == $mt['tag_body']) {
-										$tags .= "*";
-										break;
-									}
-								endforeach;
+							if (isset($me['user_id']) && $i['user_id'] == $me['user_id']) {
+								$tags .= "*";
 							}
 							
 							if (count($item_tags) > $key+1) {
@@ -1219,7 +1214,7 @@
 				}
 				?>
 				<p>
-					<input width="30" name="tags" value="<?php echo $tags;?>" />
+					<input width="30" class="input" name="tags" value="<?php echo $tags;?>" />
 					<input type="image" src="<?php echo $templatePath;?>img/go.png" name="update_tag" value="1" class="go" /><br />
 				</p>
 				
